betty.importlib module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.importlib module

Provide `import` utilities.

betty.importlib.fully_qualified_type_name(importable: Any) → str

  Get the fully qualified name for a type.

  Parameters:

    importable (`typing.Any`)

  Return type:

    `str`

betty.importlib.import_any(fully_qualified_type_name: str) → Any

  Import any symbol by its fully qualified type name.

  Parameters:

    fully_qualified_type_name (`str`)

  Return type:

    `typing.Any`